@@ -1,6 +1,6 @@
 package Resque::Worker;
 # ABSTRACT: Does the hard work of babysitting Resque::Job's
-$Resque::Worker::VERSION = '0.25';
+$Resque::Worker::VERSION = '0.26';
 use Moose;
 with 'Resque::Encoder';
 
@@ -95,7 +95,7 @@ sub work_tick {
         #while ( ! waitpid( $pid, WNOHANG ) ) { } # non-blocking has sense?
         waitpid( $pid, 0 );
         $self->log( "Forked job($pid) exited with status $?" );
-        
+
         if ($?) {
             $job->fail("Exited with status $?");
             $self->failed(1);
@@ -105,7 +105,7 @@ sub work_tick {
         undef $SIG{TERM};
         undef $SIG{INT};
         undef $SIG{QUIT};
-        
+
         $self->procline( sprintf( "Processing %s since %s", $job->queue, $timestamp ) );
         $self->perform($job);
         exit(0) unless $self->cant_fork;
@@ -134,7 +134,7 @@ sub perform {
 sub kill_child {
     my $self = shift;
     return unless $self->child;
-    
+
     if ( kill 0, $self->child ) {
         $self->log( "Killing my child: " . $self->child );
         kill 9, $self->child;
@@ -193,8 +193,13 @@ sub done_working {
 
 sub started {
     my $self = shift;
-    $self->redis->get( $self->key( worker => $self->id => 'started' ) );
-    #TODO -> parse datetime and return DT object.
+    _parsedate( $self->redis->get( $self->key( worker => $self->id => 'started' ) ) );
+}
+
+sub _parsedate {
+    my $str = pop;
+    my ( $year, $month, $day, $hour, $minute, $secs, $tz ) = $str =~ m|^(\d+)[-/](\d+)[-/](\d+) (\d+):(\d+):(\d+) (.+)$|;
+    DateTime->new( day => $day, month => $month, year => $year, hour => $hour, minute => $minute, second => $secs, time_zone => $tz );
 }
 
 sub set_started {
@@ -207,6 +212,12 @@ sub processing {
     eval { $self->encoder->decode( $self->redis->get( $self->key( worker => $self->id ) ) ) } || {};
 }
 
+sub processing_started {
+    my $self = shift;
+    my $run_at = $self->processing->{run_at} || return;
+    _parsedate($run_at);
+}
+
 sub state {
     my $self = shift;
     $self->redis->exists( $self->key( worker => $self->id ) ) ? 'working' : 'idle';
@@ -393,7 +404,7 @@ Resque::Worker - Does the hard work of babysitting Resque::Job's
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 ATTRIBUTES
 
@@ -511,9 +522,6 @@ Inform the backend this worker has done its current job
 What time did this worker start?
 Returns an instance of DateTime.
 
-TODO: not working in this release. This is returning
-a string used internally.
-
 =head2 set_started
 
 Tell Redis we've started
@@ -522,6 +530,11 @@ Tell Redis we've started
 
 Returns a hash explaining the Job we're currently processing, if any.
 
+=head2 processing_started
+
+What time did this worker started to work on current job?
+Returns an instance of DateTime or undef when it's not working.
+
 =head2 state
 
 Returns a string representing the current worker state,
